==> sutty-liquid-0.8.0.gem: lib/jekyll/filters/strings.rb <==
# frozen_string_literal: true

module Jekyll
  module Filters
    module Strings
      # String#start_with?
      def start_with(input, start)
        input.to_s.start_with? start.to_s
      end

      # Replaces the last ocurrence of a String
      #
      # @param [String]
      # @param [String]
      # @param [String]
      # @return [String]
      def replace_last(input, search, replace)
        hay = input.split search
        needle = "#{replace}#{hay.pop}"

        hay.join(search) + needle
      end

      # We often use * for inclusive language, where language is
      # gendered.  This clashes with Commonmark's understanding of
      # emphasis delimiters.
      #
      # But we want to support inclusive language and we don't
      # necessarily need to know what a escape character is to do it.
      #
      # This filter disables *emphasis* in favor of _emphasis_ and
      # escapes them.
      #
      # @see {https://spec.commonmark.org/0.30/#emphasis-and-strong-emphasis}
      # @param :input [String]
      # @return [String]
      def allow_inclusive_language_in_markdown(input)
        return if input.nil? || input.empty?
        return unless input.to_s.include? '*'

        require 'securerandom'

        # Something that can't be accidentally replaced
        star_delimiter = "||#{SecureRandom.hex}||"
        escaped_delimiter = "||#{SecureRandom.hex}||"

        # 1. Exclude escaped stars
        #
        # 2. Exclude bold
        #
        # 3. Exclude list items
        #
        # 4. Escape remaining stars
        #
        # 5. Recover original stars
        input.to_s
          .gsub('\*', escaped_delimiter)
          .gsub('**', star_delimiter * 2)
          .gsub(/^(\s*)\*/, "\\1#{star_delimiter}")
          .gsub('*', '\*')
          .gsub(star_delimiter, '*')
          .gsub(escaped_delimiter, '\*')
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::Strings)

==> sutty-liquid-0.8.1.gem: lib/jekyll/filters/strings.rb <==
# frozen_string_literal: true

module Jekyll
  module Filters
    module Strings
      # String#start_with?
      def start_with(input, start)
        input.to_s.start_with? start.to_s
      end

      # Replaces the last ocurrence of a String
      #
      # @param [String]
      # @param [String]
      # @param [String]
      # @return [String]
      def replace_last(input, search, replace)
        hay = input.split search
        needle = "#{replace}#{hay.pop}"

        hay.join(search) + needle
      end

      # We often use * for inclusive language, where language is
      # gendered.  This clashes with Commonmark's understanding of
      # emphasis delimiters.
      #
      # But we want to support inclusive language and we don't
      # necessarily need to know what a escape character is to do it.
      #
      # This filter disables *emphasis* in favor of _emphasis_ and
      # escapes them.
      #
      # @see {https://spec.commonmark.org/0.30/#emphasis-and-strong-emphasis}
      # @param :input [String]
      # @return [String]
      def allow_inclusive_language_in_markdown(input)
        return input if input.nil? || input.empty?
        return input unless input.to_s.include? '*'

        require 'securerandom'

        # Something that can't be accidentally replaced
        star_delimiter = "||#{SecureRandom.hex}||"
        escaped_delimiter = "||#{SecureRandom.hex}||"

        # 1. Exclude escaped stars
        #
        # 2. Exclude bold
        #
        # 3. Exclude list items
        #
        # 4. Escape remaining stars
        #
        # 5. Recover original stars
        input.to_s
          .gsub('\*', escaped_delimiter)
          .gsub('**', star_delimiter * 2)
          .gsub(/^(\s*)\*/, "\\1#{star_delimiter}")
          .gsub('*', '\*')
          .gsub(star_delimiter, '*')
          .gsub(escaped_delimiter, '\*')
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::Strings)
